@@ -1,35 +1,105 @@
-package NewFangle 0.0901 {
+package NewFangle 0.01 {
 
   use strict;
   use warnings;
-  use 5.014;
+  use 5.020;
   use NewFangle::FFI;
-  use NewFangle::Config;
-  use NewFangle::App;
-  use NewFangle::CustomEvent;
+  use FFI::C 0.08;
   use base qw( Exporter );
 
 # ABSTRACT: Unofficial Perl NewRelic SDK
 
 
+  FFI::C->ffi($ffi);
+
+  package NewFangle::NewrelicLoglevel 0.01 {
+    FFI::C->enum([
+      'error',
+      'warning',
+      'info',
+      'debug',
+    ], { prefix => 'NEWRELIC_LOG_' });
+  }
+
+  package NewFangle::NewrelicTransactionTracerThreshold 0.01 {
+    FFI::C->enum([
+      'is_apdex_failing',
+      'is_over_duration',
+    ], { prefix => 'NEWRELIC_THRESHOLD_' });
+  }
+
+  package NewFangle::NewrelicTtRecordsql 0.01 {
+    FFI::C->enum([
+      'off',
+      'raw',
+      'obfuscated',
+    ], { prefix => 'NEWRELIC_SQL_' });
+  }
+
+  package NewFangle::DatastoreReporting 0.01 {
+    FFI::C->struct([
+      enabled      => 'bool',
+      record_sql   => 'newrelic_tt_recordsql_t',
+      threshold_us => 'newrelic_time_us_t',
+    ]);
+  };
+
+  package NewFangle::NewrelicTransactionTracerConfig 0.01 {
+    FFI::C->struct([
+      enabled                  => 'bool',
+      threshold                => 'newrelic_transaction_tracer_threshold_t',
+      duration_us              => 'newrelic_time_us_t',
+      stack_trace_threshold_us => 'newrelic_time_us_t',
+      datastore_reporting      => 'datastore_reporting_t',
+    ]);
+  }
+
+  package NewFangle::NewrelicDatastoreSegmentConfig 0.01 {
+    FFI::C->struct([
+      instance_reporting      => 'bool',
+      database_name_reporting => 'bool',
+    ]);
+  }
+
+  package NewFangle::NewrelicDistributedTracingConfig 0.01 {
+    FFI::C->struct([
+      enabled => 'bool',
+    ]);
+  }
+
+  package NewFangle::NewrelicSpanEventConfig 0.01 {
+    FFI::C->struct([
+      enabled => 'bool',
+    ]);
+  }
+
+  package NewFangle::NewrelicAppConfig 0.01 {
+    FFI::C->struct([
+      app_name            => 'string(255)',
+      license_key         => 'string(255)',
+      redirect_collector  => 'string(100)',
+      log_filename        => 'string(512)',
+      log_level           => 'newrelic_loglevel_t',
+      transaction_tracer  => 'newrelic_transaction_tracer_config_t',
+      datastore_tracer    => 'newrelic_datastore_segment_config_t',
+      distributed_tracing => 'newrelic_distributed_tracing_config_t',
+      span_events         => 'newrelic_span_event_config_t',
+    ], { trim_string => 1 });
+  }
+
+
   $ffi->mangler(sub { $_[0] });
   $ffi->attach( newrelic_configure_log => ['string','newrelic_loglevel_t' ] => 'bool'   );
   $ffi->attach( newrelic_init          => ['string','int' ]                 => 'bool'   );
   $ffi->attach( newrelic_version       => []                                => 'string' );
-
-  if($ffi->find_symbol( 'newrelic_set_hostname' ))
-  {
-    $ffi->attach( newrelic_set_hostname => ['string'] => 'int' );
-  }
-  else
-  {
-    *newrelic_set_hostname = sub { 0 };
-  }
-
   $ffi->mangler(sub { "newrelic_$_[0]" });
 
   our @EXPORT_OK = grep /^newrelic_/, keys %NewFangle::;
 
+  require NewFangle::Config;
+  require NewFangle::App;
+  require NewFangle::CustomEvent;
+
 };
 
 1;
@@ -46,25 +116,15 @@ NewFangle - Unofficial Perl NewRelic SDK
 
 =head1 VERSION
 
-version 0.09_01
+version 0.01
 
 =head1 SYNOPSIS
 
- use NewFangle;
- my $app = NewFangle::App->new({app_name => 'MyApp', license_key => $license_key});
- my $txn = $app->start_web_transaction('my transaction');
+ use NewRelic;
+ my $app = NewRelic::App->new('MyApp', $license_key);
+ my $txn = $app->start_transaction('my transaction');
  $txn->end;
 
-Or using a L<NewFangle::Config>:
-
- use NewFangle;
- my $config = NewFangle::Config->new(
-   app_name => 'MyApp',
-   license_key => $license_key,
- );
- my $app = NewFangle::App->new($config);
- my $txn = $app->start_web_transaction('my transaction');
-
 =head1 DESCRIPTION
 
 This module provides bindings to the NewRelic C-SDK.  Since NewRelic doesn't provide
@@ -80,34 +140,13 @@ found easily.  The documentation has decent coverage of all methods, but it does
 always make sense to reproduce everything that is in the C-SDK documentation, so
 it is recommended that you review it before getting started.
 
-This module requires a running C<newrelic-daemon>.  If you forget, the service C<newrelic-infra> will return an initialization diagnostic like this:
-
- 2021-05-27 06:41:27.160 +0000 (23284 23284) error: failed to connect to the daemon using a timeout of 0 ms at the path /tmp/.newrelic.sock
- 2021-05-27 06:41:27.160 +0000 (23284 23284) error: error initialising libnewrelic; cannot create application
-
 I've called this module L<NewFangle> in the hopes that one day NewRelic will write
 native Perl bindings and they can use the more obvious NewRelic namespace.
 
-=begin html
-
-<p>On your dashboard side, you will get:</p>
-
-<div style="display: flex">
-<div style="margin: 3px; flex: 1 1 50%">
-<img alt="Test" src="NewFangle/newrelic-dashboard-result.png" style="max-width: 100%">
-</div>
-</div>
-
-=end html
-
 =head1 FUNCTIONS
 
 These may be imported on request using L<Exporter>.
 
-For instance:
-
- use NewFangle qw( newrelic_init );
-
 =head2 newrelic_configure_log
 
  my $bool = newrelic_configure_log($filename, $level);
@@ -142,22 +181,7 @@ Initialize the C SDK with non-default settings.
 
 (csdk: newrelic_version)
 
-Returns the version of the NewRelic C-SDK as a string.
-
-=head2 newrelic_set_hostname
-
- my $bool = newrelic_set_hostname($hostname);
-
-Sets the default hostname to be used in the NewRelic UI.  This is the result of
-C<gethostname> by default, but that might not be usefully meaningful when running in
-a docker or similar container.
-
-This requires a properly patched NewRelic C-SDK to work, since the base C-SDK doesn't
-currently support overriding the hostname.  If you installed with L<Alien::libnewrelic>
-then it should have been properly patched for you.
-
-Returns true if successful, false otherwise.  Normally a failure would only happen if
-the NewRelic C-SDK hadn't been patched.
+Returns the
 
 =head1 ENVIRONMENT
 
@@ -171,11 +195,6 @@ The default app name, if not specified in the configuration.
 
 The NewRelic license key.
 
-=item C<NEWRELIC_APP_HOSTNAME>
-
-The host display name that will be reported to NewRelic, if the C<libnewrelic> has been properly
-patched (see C<newrelic_set_hostname> above).
-
 =back
 
 =head1 CAVEATS
@@ -202,11 +221,7 @@ instead of C<Perl>.
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Owen Allsopp (ALLSOPP)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
