@@ -1,8 +1,8 @@
-package NewFangle::App 0.0901 {
+package NewFangle::App 0.01 {
 
   use strict;
   use warnings;
-  use 5.014;
+  use 5.020;
   use NewFangle::FFI;
   use NewFangle::Transaction;
   use Carp ();
@@ -12,13 +12,6 @@ package NewFangle::App 0.0901 {
 
   $ffi->attach( [ create_app => 'new' ] => ['newrelic_app_config_t', 'unsigned short'] => 'newrelic_app_t' => sub {
     my($xsub, undef, $config, $timeout) = @_;
-
-    if(defined $ENV{NEWRELIC_APP_HOSTNAME}) {
-      NewFangle::newrelic_set_hostname(
-        $ENV{NEWRELIC_APP_HOSTNAME}
-      );
-    }
-
     $config //= {};
     $config = NewFangle::Config->new(%$config) if ref $config eq 'HASH';
     $timeout //= $ENV{PERL_NEWFANGLE_TIMEOUT} // 0;
@@ -74,7 +67,7 @@ NewFangle::App - NewRelic application class
 
 =head1 VERSION
 
-version 0.09_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -148,11 +141,7 @@ Returns true if the app class was able to connect to the local NewRelic daemon o
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Owen Allsopp (ALLSOPP)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
