@@ -1,11 +1,10 @@
-package NewFangle::Config 0.0901 {
+package NewFangle::Config 0.01 {
 
   use strict;
   use warnings;
-  use 5.014;
+  use 5.020;
   use NewFangle::FFI;
   use FFI::C::Util ();
-  use Carp ();
 
 # ABSTRACT: NewRelic Configuration class.
 
@@ -14,7 +13,7 @@ package NewFangle::Config 0.0901 {
     my($xsub, $class, %config) = @_;
     my $app_name    = delete $config{app_name}    // $ENV{NEWRELIC_APP_NAME}    // 'AppName';
     my $license_key = delete $config{license_key} // $ENV{NEWRELIC_LICENSE_KEY} // '';
-    my $config = $xsub->($app_name, $license_key) // Carp::croak("Error creating $class, bad license key");
+    my $config = $xsub->($app_name, $license_key);
     FFI::C::Util::perl_to_c($config, \%config);
     bless {
       config => $config,
@@ -49,7 +48,7 @@ NewFangle::Config - NewRelic Configuration class.
 
 =head1 VERSION
 
-version 0.09_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -69,7 +68,7 @@ version 0.09_01
    redirect_collector => '',
    span_events => {
      enabled => 1,
-   },
+   }.
    transaction_tracer => {
      datastore_reporting => {
        enabled => 1,
@@ -122,11 +121,7 @@ Convert the configuration back to a Perl hash reference.  This may be useful to
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Owen Allsopp (ALLSOPP)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
