@@ -1,8 +1,8 @@
-package NewFangle::CustomEvent 0.0901 {
+package NewFangle::CustomEvent 0.01 {
 
   use strict;
   use warnings;
-  use 5.014;
+  use 5.020;
   use NewFangle::FFI;
   use Carp ();
 
@@ -42,15 +42,12 @@ NewFangle::CustomEvent - NewRelic custom event class
 
 =head1 VERSION
 
-version 0.09_01
+version 0.01
 
 =head1 SYNOPSIS
 
  use NewFangle;
- my $app   = NewFangle::App->new;
- my $txn   = $app->start_web_transaction("my-txn");
  my $event = NewFangle::CustomEvent->new("my event");
- $txn->record_custom_event($event);
 
 =head1 DESCRIPTION
 
@@ -100,11 +97,7 @@ Creates a NewRelic application custom event.
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Owen Allsopp (ALLSOPP)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
