@@ -1,12 +1,12 @@
-package NewFangle::Segment 0.0901 {
+package NewFangle::Segment 0.01 {
 
   use strict;
   use warnings;
-  use 5.014;
+  use 5.020;
   use NewFangle::FFI;
   use Carp ();
 
-# ABSTRACT: NewRelic segment class
+# ABSTRACT: NewRelic application class
 
 
   sub transaction { shift->{txn} }
@@ -42,11 +42,11 @@ __END__
 
 =head1 NAME
 
-NewFangle::Segment - NewRelic segment class
+NewFangle::Segment - NewRelic application class
 
 =head1 VERSION
 
-version 0.09_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ version 0.09_01
 
 =head1 DESCRIPTION
 
-NewRelic segment class
+NewRelic transaction class
 
 =head1 METHODS
 
@@ -103,11 +103,7 @@ Ends the segment.
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Owen Allsopp (ALLSOPP)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
